@@ -29,6 +29,8 @@
 #include <KLocalizedString>
 #include "isolineedit.h"
 
+#include <KPixmapSequenceLoader>
+
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent),
       m_lastOpenedDir(),
@@ -75,13 +77,12 @@ void MainWindow::setupUi()
 {
     // Logo
     QLabel *logoLabel = new QLabel;
-    logoLabel->setPixmap(KIconLoader::global()->loadIcon("drive-removable-media", KIconLoader::Desktop));
+    logoLabel->setPixmap(KIconLoader::global()->loadIcon("org.kde.isoimagewriter", KIconLoader::Desktop));
     logoLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
     QLabel *titleLabel = new QLabel;
     titleLabel->setTextFormat(Qt::RichText);
-    titleLabel->setText("<h2 style='margin-bottom: 0;'>KDE ISO Image Writer</h2>"
-                        "A quick and simple way to create a bootable USB drive.");
+    titleLabel->setText(QStringLiteral("<h2 style='margin-bottom: 0;'>%1</h2>%2").arg(i18n("KDE ISO Image Writer")).arg(i18n("A quick and simple way to create a bootable USB drive.")));
 
     QHBoxLayout *headerHBoxLayout = new QHBoxLayout;
     headerHBoxLayout->addWidget(logoLabel);
@@ -180,6 +181,7 @@ QWidget* MainWindow::createConfirmWidget()
 
     QProgressBar *downloadProgressBar = new QProgressBar();
     downloadProgressBar->setVisible(false);
+    downloadProgressBar->setFormat(i18nc("Progress percent value", "%1%"));
     downloadProgressBar->setMinimum(0);
     downloadProgressBar->setMaximum(100);
     connect(this, &MainWindow::downloadProgressChanged, downloadProgressBar, &QProgressBar::show);
@@ -217,6 +219,7 @@ QWidget* MainWindow::createProgressWidget()
     messageLabel->setWordWrap(true);
 
     m_progressBar = new QProgressBar;
+    m_progressBar->setFormat(i18nc("Progress percent value", "%1%"));
     m_cancelButton = new QPushButton(i18n("Cancel"));
 
     QVBoxLayout *mainVBoxLayout = new QVBoxLayout;
@@ -285,7 +288,8 @@ void MainWindow::preprocessIsoImage(const QString& isoImagePath)
     // Verify ISO image
     m_busyLabel->setText(i18n("Verifying ISO image"));
     m_busyWidget->show();
-    m_busySpinner->setSequence(KIconLoader::global()->loadPixmapSequence("process-working", KIconLoader::SizeSmallMedium));
+    m_busySpinner->setSequence(KPixmapSequenceLoader::load(
+        "process-working", KIconLoader::SizeSmallMedium));
     m_busySpinner->start();
 
     IsoVerifier *isoVerifier = new IsoVerifier(m_isoImagePath);
@@ -505,7 +509,8 @@ void MainWindow::openUrl(const QUrl& url)
     });
     m_busyLabel->setText(i18n("Downloading ISO image"));
     m_busyWidget->show();
-    m_busySpinner->setSequence(KIconLoader::global()->loadPixmapSequence("process-working", KIconLoader::SizeSmallMedium));
+    m_busySpinner->setSequence(KPixmapSequenceLoader::load(
+        "process-working", KIconLoader::SizeSmallMedium));
     m_busySpinner->start();
     m_fetchIso->fetch(url);
 }
@@ -622,10 +627,11 @@ void MainWindow::showIsoVerificationResult(IsoVerifier::VerifyResult verify, con
 {
     if (verify == IsoVerifier::VerifyResult::Successful) {
         m_busyLabel->setText(i18n("The ISO image is valid"));
-        m_busySpinner->setSequence(KIconLoader::global()->loadPixmapSequence("checkmark", KIconLoader::SizeSmallMedium));
+        m_busySpinner->setSequence(KPixmapSequenceLoader::load(
+            "checkmark", KIconLoader::SizeSmallMedium));
     } else {
-        m_busySpinner->setSequence(KIconLoader::global()->loadPixmapSequence("error", KIconLoader::SizeSmallMedium));
-
+        m_busySpinner->setSequence(
+            KPixmapSequenceLoader::load("error", KIconLoader::SizeSmallMedium));
         if (verify == IsoVerifier::VerifyResult::KeyNotFound) {
             m_busyLabel->setText(i18n("Could not find the key to verify the ISO image"));
         } else if (verify == IsoVerifier::VerifyResult::Failed) {
